@@ -24,6 +24,8 @@ from contextlib import contextmanager, nullcontext, suppress
 from glob import glob
 from time import sleep
 
+from distributed.scheduler import Scheduler
+
 try:
     import ssl
 except ImportError:
@@ -551,6 +553,10 @@ def client(loop, cluster_fixture):
         yield client
 
 
+# Compatibility. A lot of tests simply use `c` as fixture name
+c = client
+
+
 @pytest.fixture
 def client_secondary(loop, cluster_fixture):
     scheduler, workers = cluster_fixture
@@ -772,10 +778,6 @@ def gen_test(timeout=_TEST_TIMEOUT):
     return _
 
 
-from .scheduler import Scheduler
-from .worker import Worker
-
-
 async def start_cluster(
     nthreads,
     scheduler_addr,
@@ -1479,6 +1481,7 @@ def check_instances():
     Worker._instances.clear()
     Scheduler._instances.clear()
     SpecCluster._instances.clear()
+    Worker._initialized_clients.clear()
     # assert all(n.status == "closed" for n in Nanny._instances), {
     #     n: n.status for n in Nanny._instances
     # }
@@ -1502,6 +1505,12 @@ def check_instances():
                 w.loop.add_callback(w.close)
     Worker._instances.clear()
 
+    start = time()
+    while any(c.status != "closed" for c in Worker._initialized_clients):
+        sleep(0.1)
+        assert time() < start + 10
+    Worker._initialized_clients.clear()
+
     for i in range(5):
         if all(c.closed() for c in Comm._instances):
             break
